@@ -28,7 +28,7 @@ except ImportError:
     pass  # No harm if the module isn't located
 import displayio
 
-__version__ = "2.3.8"
+__version__ = "2.3.10"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_ProgressBar.git"
 
 
@@ -78,7 +78,6 @@ class ProgressBarBase(displayio.TileGrid):
         margin_size: int = 1,
         value_range: Union[Tuple[int, int], Tuple[float, float]] = (0, 100),
     ) -> None:
-
         if value_range[0] >= value_range[1]:
             raise ValueError("The minimum value must be less than the maximum value")
 
@@ -490,12 +489,12 @@ class ProgressBarBase(displayio.TileGrid):
 
         return (float(value) - self.minimum) / (self.maximum - self.minimum)
 
-    @classmethod
-    def _get_value_sizes(cls, _old_ratio: float, _new_ratio: float) -> Tuple[int, int]:
+    # pylint: disable=no-self-use
+    def _get_value_sizes(self, _old_ratio: float, _new_ratio: float) -> Tuple[int, int]:
         return 0, 0
 
-    @classmethod
-    def _get_max_fill_size(cls) -> int:
+    # pylint: disable=no-self-use
+    def _get_max_fill_size(self) -> int:
         return 0
 
     def _get_ratios(
@@ -521,8 +520,8 @@ class ProgressBarBase(displayio.TileGrid):
     def _get_sizes_min_max(self) -> Tuple[int, int]:
         return 0, min(self.fill_width(), self.fill_height())
 
-    @classmethod
-    def _invert_fill_direction(cls) -> bool:
+    # pylint: disable=no-self-use
+    def _invert_fill_direction(self) -> bool:
         return False
 
     def _get_horizontal_fill(
